@@ -1,5 +1,6 @@
 import sys
 from polly import application_error_info as app_err_info
+from polly import http_response_codes as http_res_codes
 
 sys.tracebacklimit = 0
 
@@ -169,6 +170,11 @@ class InvalidFormatException(Exception):
         return "This file format is not supported."
 
 
+class UnsupportedRepositoryException(Exception):
+    def __str__(self):
+        return "Report Generation feature is enabled for 'GEO' repository. Please try again."
+
+
 class paramException(BaseExceptionError):
     detail = app_err_info.PARAM_EXCEPTION
 
@@ -211,6 +217,49 @@ class invalidApiResponseException(BaseExceptionError):
             self.detail = detail
 
 
+class BadRequestError(BaseExceptionError):
+    status = http_res_codes.BAD_REQUEST
+    code = app_err_info.BAD_REQUEST_CODE
+    title = app_err_info.BAD_REQUEST_TITLE
+    detail = app_err_info.BAD_REQUEST_DETAIL
+
+    def __init__(self, code=None, status=None, title=None, detail=None):
+        if code:
+            self.code = code
+        if status:
+            self.status = status
+        if title:
+            self.title = title
+        if detail:
+            self.detail = detail
+
+
+class AccessDeniedError(BaseExceptionError):
+    status = http_res_codes.FORBIDDEN
+    code = app_err_info.FORBIDDEN_CODE
+    title = app_err_info.FORBIDDEN_TITLE
+    detail = app_err_info.FORBIDDEN_DETAIL
+
+    def __init__(self, title=None, detail=None):
+        if title:
+            self.title = title
+        if detail:
+            self.detail = detail
+
+
+class ResourceNotFoundError(BaseExceptionError):
+    status = http_res_codes.NOT_FOUND
+    code = app_err_info.NOT_FOUND_CODE
+    title = app_err_info.NOT_FOUND_TITLE
+    detail = app_err_info.NOT_FOUND_DETAIL
+
+    def __init__(self, title=None, detail=None):
+        if title:
+            self.title = title
+        if detail:
+            self.detail = detail
+
+
 def error_handler(response):
     if has_error_message(response):
         title, detail = extract_json_api_error(response)
@@ -235,8 +284,10 @@ def extract_json_api_error(response):
     error = response.json().get("error")
     if error is None:
         error = response.json().get("errors")[0]
-    title = error.get("title")
-    detail = error.get("detail")
+    if "title" in error:
+        title = error.get("title")
+    if "detail" in error:
+        detail = error.get("detail")
     return title, detail
 
 
